#
# src/kernel/Makefile
#

##include /crux-arm/toolchain/vars.mk
include /crux-arm/ct-ng/vars.mk

#TARGET = arm-crux-linux-gnueabi
#WORK = $(PWD)/work
#CLFS = /crux-arm/clfs
#CROSSTOOLS = /opt/crosstools

KERNEL_VERSION = 2.6.34.6

MATT_PATCHSET = linux-2.6.34-ts7200_matt-2

.PHONY: all clean image modules map config patch

all: image modules map

clean: image-clean modules-clean map-clean patch-clean

distclean: clean image-distclean modules-distclean map-distclean patch-distclean

$(WORK)/linux-$(KERNEL_VERSION).tar.bz2:
	wget -P $(WORK) ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$(KERNEL_VERSION).tar.bz2

$(WORK)/linux-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION).tar.bz2 config-$(KERNEL_VERSION)
	tar -C $(WORK) -xvjf $(WORK)/linux-$(KERNEL_VERSION).tar.bz2
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		make mrproper && \
		make ARCH=arm ep93xx_defconfig
	touch $(WORK)/linux-$(KERNEL_VERSION)

$(WORK)/zImage-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(CROSSTOOLS)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- zImage
	cp -v $(WORK)/linux-$(KERNEL_VERSION)/arch/arm/boot/zImage $(WORK)/zImage-$(KERNEL_VERSION)
	touch $(WORK)/zImage-$(KERNEL_VERSION)

image: $(WORK)/zImage-$(KERNEL_VERSION)

image-clean:
	rm -vrf $(WORK)/linux-$(KERNEL_VERSION) $(WORK)/zImage-$(KERNEL_VERSION)

image-distclean: image-clean

$(WORK)/modules-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(LD_LIBRARY_PATH)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- modules && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- INSTALL_MOD_PATH=$(WORK)/modules-$(KERNEL_VERSION) modules_install
	rm -f $(WORK)/modules-$(KERNEL_VERSION)/lib/modules/$(KERNEL_VERSION)/{source,build}
	touch $(WORK)/modules-$(KERNEL_VERSION)

modules: $(WORK)/modules-$(KERNEL_VERSION)

modules-clean:
	rm -vrf $(WORK)/modules-$(KERNEL_VERSION)

modules-distclean: modules-clean

$(WORK)/System.map-$(KERNEL_VERSION): $(WORK)/linux-$(KERNEL_VERSION)
	cp $(WORK)/linux-$(KERNEL_VERSION)/System.map $(WORK)/System.map-$(KERNEL_VERSION)
	touch $(WORK)/System.map-$(KERNEL_VERSION)

map: $(WORK)/System.map-$(KERNEL_VERSION)

map-clean:
	rm -vrf $(WORK)/System.map-$(KERNEL_VERSION)

map-distclean: map-clean

config: $(WORK)/linux-$(KERNEL_VERSION)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		export PATH=$(CROSSTOOLS)/bin:$$PATH && \
		export LD_LIBRARY_PATH=$(CROSSTOOLS)/lib:$$LD_LIBRARY_PATH && \
		make ARCH=arm CROSS_COMPILE=$(TARGET)- menuconfig
	touch $(WORK)/linux-$(KERNEL_VERSION)


$(WORK)/$(MATT_PATCHSET).tar.gz:
	wget -P $(WORK) http://mcrapet.free.fr/$(MATT_PATCHSET).tar.gz

$(WORK)/$(MATT_PATCHSET): $(WORK)/$(MATT_PATCHSET).tar.gz
	tar -C $(WORK) -xvzf $(WORK)/$(MATT_PATCHSET).tar.gz

patch: $(WORK)/linux-$(KERNEL_VERSION) $(WORK)/$(MATT_PATCHSET)
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		patch -p1 < $(WORK)/$(MATT_PATCHSET)/$(MATT_PATCHSET).patch	
	cp $(WORK)/$(MATT_PATCHSET)/configs/* $(WORK)/linux-$(KERNEL_VERSION)/arch/arm/configs/
	cd $(WORK)/linux-$(KERNEL_VERSION) && \
		make ARCH=arm ts72xx_eabi_small_defconfig

patch-clean:
	rm -vrf $(WORK)/$(MATT_PATCHSET) $(WORK)/$(MATT_PATCHSET).tar.gz

patch-distclean: patch-clean

# End of file
